@@ -17,7 +17,7 @@ HEADERS = {
 def is_enabled(): return ENABLED
 
 
-def _id_to_level(id: str): return id.count('.')
+def id_to_level(id: str): return id.count('.')
 
 
 def fetch_data(**kwargs):
@@ -31,7 +31,7 @@ def fetch_data(**kwargs):
 def get_region_id(gid: str, **kwargs):
     # make sure we are not using an old url
     try:
-        level = _id_to_level(gid)
+        level = id_to_level(gid)
         field = f"GID_{level}"
         id = fetch_data(collection=f"users/hestiaplatform/gadm36_{level}",
                         ee_type='vector',
