@@ -1,3 +1,5 @@
+import importlib
+import json
 from typing import List
 from functools import reduce
 from datetime import datetime
@@ -12,6 +14,14 @@ def _filter_list_errors(values: list, return_single=True):
     return True if return_single and len(values) == 0 else (values[0] if return_single and len(values) == 1 else values)
 
 
+def _list_except_item(values: list, item):
+    try:
+        idx = values.index(item)
+        return values[:idx] + values[idx+1:]
+    except ValueError:
+        return values
+
+
 def update_error_path(error: dict, key: str, index=None):
     path = f".{key}[{index}]{error.get('dataPath')}" if index is not None else f".{key}{error.get('dataPath')}"
     return {**error, **{'dataPath': path}}
@@ -24,6 +34,16 @@ def _safe_cast(val, to_type, default=None):
         return default
 
 
+def _is_same_dict(a: dict, b: dict): return json.dumps(a, sort_keys=True) == json.dumps(b, sort_keys=True)
+
+
+def _dict_without_key(a: dict, key: str):
+    no_key = a.copy()
+    if key in no_key:
+        no_key.pop(key)
+    return no_key
+
+
 def _get_by_key(x, y):
     return x if x is None else (
         x.get(y) if isinstance(x, dict) else list(map(lambda v: _get_dict_key(v, y), x))
@@ -38,10 +58,6 @@ def _value_range_error(value: int, minimum: int, maximum: int):
         'maximum' if maximum is not None and value > maximum else False
 
 
-def _list_has_props(values: List[dict], props: List[str]):
-    return filter(lambda x: all(prop in x for prop in props), values)
-
-
 def _list_sum(values: list, prop: str): return sum(map(lambda v: _safe_cast(v.get(prop, 0), float, 0.0), values))
 
 
@@ -76,3 +92,51 @@ def _find_linked_node(nodes: list, linked_node: dict):
 
 
 def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
+
+
+def _import_model(name: str):
+    return importlib.import_module(f"hestia_earth.models.{name}").run
+
+
+def run_model(model: str, term_id: str, data: dict):
+    """
+    Run a Hestia model from the engine models library.
+
+    Parameters
+    ----------
+    model : str
+        The name of the model to run.
+    term_id : str
+        The term to run the model on.
+    data : dict
+        The data used to run the model.
+
+    Returns
+    -------
+    Any
+        The result of the model, which can be a single `dict` or a list of `dict`s.
+    """
+    return _import_model(model)(term_id, data)
+
+
+def run_model_from_node(node: dict, data: dict):
+    """
+    Run a Hestia model from the engine models library.
+    To use this function, you need to use a Blank Node that contains a `methodModel` and a `term`,
+    otherwise you need to use the `run_model` method.
+
+    Parameters
+    ----------
+    node : dict
+        The Blank Node containing a `methodModel` and a `Term`.
+    data : dict
+        The data used to run the model.
+
+    Returns
+    -------
+    Any
+        The result of the model, which can be a single `dict` or a list of `dict`s.
+    """
+    methodModel = node.get('methodModel', {}).get('@id')
+    term_id = node.get('term', {}).get('@id')
+    return run_model(methodModel, term_id, data)
