@@ -3,7 +3,7 @@ from hestia_earth.schema import SchemaType
 from hestia_earth.utils.tools import flatten
 
 from hestia_earth.validation.utils import update_error_path
-from .shared import validate_empty_fields
+from .shared import validate_empty_fields, validate_nodes_duplicates
 from .cycle import validate_cycle
 from .impact_assessment import validate_impact_assessment
 from .organisation import validate_organisation
@@ -21,8 +21,7 @@ VALIDATE_TYPE = {
 
 def _validate_node_type(nodes: list, ntype: str, node: dict):
     validations = VALIDATE_TYPE[ntype](node, nodes) if ntype in VALIDATE_TYPE else []
-    empty_warnings = validate_empty_fields(node)
-    return validations + empty_warnings
+    return validations + validate_empty_fields(node) + validate_nodes_duplicates(node, nodes)
 
 
 def _validate_node_children(nodes: list, node: dict):
