@@ -8,14 +8,15 @@ from hestia_earth.validation.validators.cycle import (
     validate_functionalUnitMeasure,
     validate_economicValueShare,
     validate_sum_aboveGroundCropResidue,
-    validate_crop_residue_completeness
+    validate_crop_residue_completeness,
+    validate_siteDuration, validate_otherSites_length, validate_otherSites_cycleDuration
 )
 
 
 def test_validate_valid():
     with open(f"{fixtures_path}/cycle/valid.json") as f:
         node = json.load(f)
-    assert validate_cycle(node) == [True] * 29
+    assert validate_cycle(node) == [True] * 38
 
 
 def test_validate_cycle_dates_valid():
@@ -23,17 +24,17 @@ def test_validate_cycle_dates_valid():
         'startDate': '2020-01-01',
         'endDate': '2020-01-02'
     }
-    assert validate_cycle_dates(cycle)
+    assert validate_cycle_dates(cycle) is True
     cycle = {
         'startDate': '2020-01',
         'endDate': '2020-01'
     }
-    assert validate_cycle_dates(cycle)
+    assert validate_cycle_dates(cycle) is True
     cycle = {
         'startDate': '2020',
         'endDate': '2020'
     }
-    assert validate_cycle_dates(cycle)
+    assert validate_cycle_dates(cycle) is True
 
 
 def test_validate_cycle_dates_invalid():
@@ -63,7 +64,7 @@ def test_validate_cycleDuration_valid():
         'endDate': '2021-01-01',
         'cycleDuration': 365
     }
-    assert validate_cycleDuration(cycle)
+    assert validate_cycleDuration(cycle) is True
 
 
 def test_validate_cycleDuration_invalid():
@@ -86,7 +87,7 @@ def test_validate_functionalUnitMeasure_valid():
     site = {
         'siteType': 'cropland'
     }
-    assert validate_functionalUnitMeasure(cycle, site)
+    assert validate_functionalUnitMeasure(cycle, site) is True
 
 
 def test_validate_functionalUnitMeasure_invalid():
@@ -109,7 +110,7 @@ def test_validate_economicValueShare_valid():
     }, {
         'economicValueShare': 80
     }]
-    assert validate_economicValueShare(products)
+    assert validate_economicValueShare(products) is True
 
 
 def test_validate_economicValueShare_invalid():
@@ -133,7 +134,7 @@ def test_validate_economicValueShare_invalid():
 def test_validate_sum_aboveGroundCropResidue_valid():
     with open(f"{fixtures_path}/cycle/aboveGroundCropResidue/valid.json") as f:
         data = json.load(f)
-    assert validate_sum_aboveGroundCropResidue(data.get('products'))
+    assert validate_sum_aboveGroundCropResidue(data.get('products')) is True
 
 
 def test_validate_sum_aboveGroundCropResidue_invalid():
@@ -150,7 +151,7 @@ def test_validate_sum_aboveGroundCropResidue_invalid():
 def test_validate_crop_residue_completeness_valid():
     with open(f"{fixtures_path}/cycle/dataCompleteness-cropResidue/valid.json") as f:
         data = json.load(f)
-    assert validate_crop_residue_completeness(data, data.get('site'))
+    assert validate_crop_residue_completeness(data, data.get('site')) is True
 
 
 def test_validate_crop_residue_completeness_invalid():
@@ -161,3 +162,67 @@ def test_validate_crop_residue_completeness_invalid():
         'dataPath': '.products',
         'message': 'the sum of above ground crop residue and below ground crop residue must be greater than zero'
     }
+
+
+def test_validate_siteDuration_valid():
+    with open(f"{fixtures_path}/cycle/siteDuration/valid.json") as f:
+        data = json.load(f)
+    assert validate_siteDuration(data) is True
+
+    with open(f"{fixtures_path}/cycle/siteDuration/valid-no-siteDuration.json") as f:
+        data = json.load(f)
+    assert validate_siteDuration(data) is True
+
+
+def test_validate_siteDuration_invalid():
+    with open(f"{fixtures_path}/cycle/siteDuration/invalid.json") as f:
+        data = json.load(f)
+    assert validate_siteDuration(data) == {
+        'level': 'error',
+        'dataPath': '.siteDuration',
+        'message': 'must be equal to cycleDuration'
+    }
+
+    with open(f"{fixtures_path}/cycle/siteDuration/invalid-otherSites.json") as f:
+        data = json.load(f)
+    assert validate_siteDuration(data) == {
+        'level': 'error',
+        'dataPath': '.siteDuration',
+        'message': 'must not be equal to cycleDuration'
+    }
+
+
+def test_validate_otherSites_length_valid():
+    with open(f"{fixtures_path}/cycle/otherSites/length/valid.json") as f:
+        data = json.load(f)
+    assert validate_otherSites_length(data) is True
+
+
+def test_validate_otherSites_length_invalid():
+    with open(f"{fixtures_path}/cycle/otherSites/length/invalid.json") as f:
+        data = json.load(f)
+    assert validate_otherSites_length(data) == {
+        'level': 'error',
+        'dataPath': '.otherSitesDuration',
+        'message': 'must have the same length as otherSites'
+    }
+
+
+def test_validate_otherSites_cycleDuration_valid():
+    with open(f"{fixtures_path}/cycle/otherSites/cycleDuration/valid.json") as f:
+        data = json.load(f)
+    assert validate_otherSites_cycleDuration(data) is True
+
+    with open(f"{fixtures_path}/cycle/otherSites/cycleDuration/valid-no-siteDuration.json") as f:
+        data = json.load(f)
+    assert validate_siteDuration(data) is True
+
+
+def test_validate_otherSites_cycleDuration_invalid():
+    with open(f"{fixtures_path}/cycle/otherSites/cycleDuration/invalid.json") as f:
+        data = json.load(f)
+    assert validate_otherSites_cycleDuration(data) == {
+        'level': 'error',
+        'dataPath': '.cycleDuration',
+        'message': 'must be equal to the sum of siteDuration and otherSitesDuration'
+    }
