@@ -10,7 +10,7 @@ from hestia_earth.validation.validators.site import (
 def test_validate_valid():
     with open(f"{fixtures_path}/site/valid.json") as f:
         node = json.load(f)
-    assert validate_site(node) == [True] * 19
+    assert validate_site(node) == [True] * 20
 
 
 def test_validate_site_dates_valid():
@@ -18,7 +18,7 @@ def test_validate_site_dates_valid():
         'startDate': '2020-01-01',
         'endDate': '2020-01-02'
     }
-    assert validate_site_dates(site)
+    assert validate_site_dates(site) is True
 
 
 def test_validate_site_dates_invalid():
@@ -39,9 +39,9 @@ def test_need_validate_coordinates():
 
     site['latitude'] = 0
     site['longitude'] = 0
-    assert validate_site_coordinates(site)
+    assert validate_site_coordinates(site) is True
 
-    site['siteType'] = SiteSiteType.AQUACULTURE_PENS
+    site['siteType'] = SiteSiteType.SEA_OR_OCEAN.value
     assert not validate_site_coordinates(site)
 
 
@@ -51,14 +51,14 @@ def test_validate_siteType_valid():
         'latitude': 44.18753,
         'longitude': -0.62521
     }
-    assert validate_siteType(site)
+    assert validate_siteType(site) is True
 
     site = {
         'siteType': SiteSiteType.CROPLAND.value,
         'latitude': 44.5096,
         'longitude': 0.40749
     }
-    assert validate_siteType(site)
+    assert validate_siteType(site) is True
 
 
 def test_validate_siteType_invalid():
